==> openshift-model-console-5.11.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsolePluginProxyFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent<A>{
  public ConsolePluginProxyFluentImpl() {
  }
  public ConsolePluginProxyFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy instance) {
    this.withServices(instance.getServices()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> services =  new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToServices(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(index >= 0 ? index : _visitables.get("services").size(), builder);this.services.add(index >= 0 ? index : services.size(), builder); return (A)this;
  }
  public A setToServices(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);
    if (index < 0 || index >= _visitables.get("services").size()) { _visitables.get("services").add(builder); } else { _visitables.get("services").set(index, builder);}
    if (index < 0 || index >= services.size()) { services.add(builder); } else { services.set(index, builder);}
     return (A)this;
  }
  public A addToServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A addAllToServices(java.util.Collection<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> items) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A removeFromServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeAllFromServices(java.util.Collection<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> items) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServices(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    if (services == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> each = services.iterator();
    final List visitables = _visitables.get("services");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServices instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> getServices() {
    return build(services);
  }
  public java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> buildServices() {
    return build(services);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildService(java.lang.Integer index) {
    return this.services.get(index).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildFirstService() {
    return this.services.get(0).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildLastService() {
    return this.services.get(services.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServices(java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> services) {
    if (this.services != null) { _visitables.get("services").removeAll(this.services);}
    if (services != null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>(); for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : services){this.addToServices(item);}} else { this.services = null;} return (A) this;
  }
  public A withServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... services) {
    if (this.services != null) {this.services.clear();}
    if (services != null) {for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item :services){ this.addToServices(item);}} return (A) this;
  }
  public java.lang.Boolean hasServices() {
    return services != null && !services.isEmpty();
  }
  public A addNewService(java.lang.Boolean authorize,java.lang.String caCertificate,java.lang.String name,java.lang.String namespace,java.lang.Integer port) {
    return (A)addToServices(new ConsolePluginProxyService(authorize, caCertificate, name, namespace, port));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> addNewService() {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> addNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> setNewServiceLike(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editService(java.lang.Integer index) {
    if (services.size() <= index) throw new RuntimeException("Can't edit services. Index exceeds size.");
    return setNewServiceLike(index, buildService(index));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editFirstService() {
    if (services.size() == 0) throw new RuntimeException("Can't edit first services. The list is empty.");
    return setNewServiceLike(0, buildService(0));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editLastService() {
    int index = services.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last services. The list is empty.");
    return setNewServiceLike(index, buildService(index));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<services.size();i++) { 
    if (predicate.test(services.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching services. No match found.");
    return setNewServiceLike(index, buildService(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyFluentImpl that = (ConsolePluginProxyFluentImpl) o;
    if (services != null ? !services.equals(that.services) :that.services != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(services,  additionalProperties,  super.hashCode());
  }
  public class ServicesNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<N>> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServicesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(this, item);
    }
    ServicesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ConsolePluginProxyFluentImpl.this.setToServices(index,builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-5.12.2-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsolePluginProxyFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent<A>{
  public ConsolePluginProxyFluentImpl() {
  }
  public ConsolePluginProxyFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxy instance) {
    this.withServices(instance.getServices()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> services =  new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToServices(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(index >= 0 ? index : _visitables.get("services").size(), builder);this.services.add(index >= 0 ? index : services.size(), builder); return (A)this;
  }
  public A setToServices(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);
    if (index < 0 || index >= _visitables.get("services").size()) { _visitables.get("services").add(builder); } else { _visitables.get("services").set(index, builder);}
    if (index < 0 || index >= services.size()) { services.add(builder); } else { services.set(index, builder);}
     return (A)this;
  }
  public A addToServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A addAllToServices(java.util.Collection<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> items) {
    if (this.services == null) {this.services = new java.util.ArrayList<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder>();}
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A removeFromServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeAllFromServices(java.util.Collection<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> items) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : items) {io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServices(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    if (services == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> each = services.iterator();
    final List visitables = _visitables.get("services");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServices instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> getServices() {
    return build(services);
  }
  public java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> buildServices() {
    return build(services);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildService(java.lang.Integer index) {
    return this.services.get(index).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildFirstService() {
    return this.services.get(0).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildLastService() {
    return this.services.get(services.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService buildMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServices(java.util.List<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService> services) {
    if (this.services != null) { _visitables.get("services").removeAll(this.services);}
    if (services != null) {this.services = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item : services){this.addToServices(item);}} else { this.services = null;} return (A) this;
  }
  public A withServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... services) {
    if (this.services != null) {this.services.clear();}
    if (services != null) {for (io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item :services){ this.addToServices(item);}} return (A) this;
  }
  public java.lang.Boolean hasServices() {
    return services != null && !services.isEmpty();
  }
  public A addNewService(java.lang.Boolean authorize,java.lang.String caCertificate,java.lang.String name,java.lang.String namespace,java.lang.Integer port) {
    return (A)addToServices(new ConsolePluginProxyService(authorize, caCertificate, name, namespace, port));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> addNewService() {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl();
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> addNewServiceLike(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> setNewServiceLike(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
    return new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluentImpl.ServicesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editService(java.lang.Integer index) {
    if (services.size() <= index) throw new RuntimeException("Can't edit services. Index exceeds size.");
    return setNewServiceLike(index, buildService(index));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editFirstService() {
    if (services.size() == 0) throw new RuntimeException("Can't edit first services. The list is empty.");
    return setNewServiceLike(0, buildService(0));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editLastService() {
    int index = services.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last services. The list is empty.");
    return setNewServiceLike(index, buildService(index));
  }
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<A> editMatchingService(java.util.function.Predicate<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<services.size();i++) { 
    if (predicate.test(services.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching services. No match found.");
    return setNewServiceLike(index, buildService(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyFluentImpl that = (ConsolePluginProxyFluentImpl) o;
    if (services != null ? !services.equals(that.services) :that.services != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(services,  additionalProperties,  super.hashCode());
  }
  public class ServicesNestedImpl<N> extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<N>> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyFluent.ServicesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServicesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(this, item);
    }
    ServicesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder(this);
    }
    io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ConsolePluginProxyFluentImpl.this.setToServices(index,builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}
